==> v0.1.0.tar.gz: proto_gorm/src/main.go <==
package main

import (
	"context"
	"flag"
	"log"
	"net"
	"net/http"

	gw "git.alfi.li/gamelang/proto_gorm/proto/gen/go" // Update
	"github.com/golang/glog"
	"github.com/grpc-ecosystem/grpc-gateway/v2/runtime"
	"github.com/jinzhu/gorm"
	_ "github.com/jinzhu/gorm/dialects/sqlite"
	"google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

var (
	// command-line options:
	// gRPC server endpoint
	grpcServerEndpoint = flag.String("grpc-server-endpoint", "localhost:9090", "gRPC server endpoint")
)

type IntPointServiceServer struct {
	gw.UnimplementedIntPointServiceServer

	dbClient *gorm.DB
}

func (IPS IntPointServiceServer) Create(ctx context.Context, CIPR *gw.CreateIntPointRequest) (*gw.CreateIntPointResponse, error) {
	log.Printf("incomming create request:/n%v+\n", *CIPR)
	IP, err := CIPR.Payload.ToORM(ctx)
	if err != nil {
		log.Fatalln("Create: error converting ToORM: ", err.Error())
	}
	log.Println("Creating ", IP)
	IPS.dbClient.Create(IP)
	return nil, status.Errorf(codes.Unimplemented, "method Create not implemented")
}

func run() error {
	ctx := context.Background()
	ctx, cancel := context.WithCancel(ctx)
	defer cancel()

	// init DB
	db, err := gorm.Open("sqlite3", "test.db")
	if err != nil {
		panic("failed to connect database")
	}
	defer db.Close()
	dbC := gw.IntPointServiceDefaultServer{}
	dbC.DB = db

	lis, err := net.Listen("tcp", *grpcServerEndpoint)
	if err != nil {
		log.Fatalf("failed to listen: %v", err)
	}
	var serverOpts []grpc.ServerOption
	grpcServer := grpc.NewServer(serverOpts...)
	gw.RegisterIntPointServiceServer(grpcServer, IntPointServiceServer{dbClient: db})
	go grpcServer.Serve(lis)
	log.Println("grpc server started")

	// Register gRPC server endpoint
	// Note: Make sure the gRPC server is running properly and accessible
	mux := runtime.NewServeMux()
	dialOpts := []grpc.DialOption{grpc.WithInsecure()}
	err = gw.RegisterIntPointServiceHandlerFromEndpoint(ctx, mux, *grpcServerEndpoint, dialOpts)
	if err != nil {
		return err
	}

	// Start HTTP server (and proxy calls to gRPC server endpoint)
	return http.ListenAndServe(":8081", mux)
}

func main() {
	flag.Parse()
	defer glog.Flush()

	if err := run(); err != nil {
		glog.Fatal(err)
	}
}

==> v0.1.5.tar.gz: proto_gorm/src/main.go <==
package main

import (
	"context"
	"flag"
	"log"
	"net"
	"net/http"

	gw "git.alfi.li/gamelang/proto_gorm/proto/gen/go" // Update
	"github.com/golang/glog"
	"github.com/grpc-ecosystem/grpc-gateway/v2/runtime"
	"github.com/jinzhu/gorm"
	_ "github.com/jinzhu/gorm/dialects/sqlite"
	"google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

var (
	// command-line options:
	// gRPC server endpoint
	grpcServerEndpoint = flag.String("grpc-server-endpoint", "localhost:9090", "gRPC server endpoint")
)

type IntPointServiceServer struct {
	gw.UnimplementedIntPointServiceServer

	DBServer *gw.IntPointServiceDefaultServer
}

func NewIntPointServiceServer(db *gw.IntPointServiceDefaultServer) *IntPointServiceServer {
	IPS := IntPointServiceServer{DBServer: db}
	db.DB.AutoMigrate(&gw.IntPoint{})
	return &IPS
}

func (IPS IntPointServiceServer) Create(ctx context.Context, request *gw.CreateIntPointRequest) (*gw.CreateIntPointResponse, error) {
	response, err := IPS.DBServer.Create(ctx, request)
	if err != nil {
		log.Println(err.Error())
		return nil, status.Errorf(codes.Internal, err.Error())
	}
	return response, nil
}

func (IPS IntPointServiceServer) Read(ctx context.Context, request *gw.ReadIntPointRequest) (*gw.ReadIntPointResponse, error) {
	response, err := IPS.DBServer.Read(ctx, request)
	if err != nil {
		log.Println(err.Error())
		return nil, status.Errorf(codes.Internal, err.Error())
	}
	return response, nil
}

func run() error {
	ctx := context.Background()
	ctx, cancel := context.WithCancel(ctx)
	defer cancel()

	// init DB
	db, err := gorm.Open("sqlite3", "test.db")
	if err != nil {
		panic("failed to connect database")
	}
	defer db.Close()
	dbC := gw.IntPointServiceDefaultServer{}
	dbC.DB = db

	lis, err := net.Listen("tcp", *grpcServerEndpoint)
	if err != nil {
		log.Fatalf("failed to listen: %v", err)
	}
	var serverOpts []grpc.ServerOption
	grpcServer := grpc.NewServer(serverOpts...)
	gw.RegisterIntPointServiceServer(grpcServer, NewIntPointServiceServer(&dbC))
	go grpcServer.Serve(lis)
	log.Println("grpc server started")

	// Register gRPC server endpoint
	// Note: Make sure the gRPC server is running properly and accessible
	mux := runtime.NewServeMux()
	dialOpts := []grpc.DialOption{grpc.WithInsecure()}
	err = gw.RegisterIntPointServiceHandlerFromEndpoint(ctx, mux, *grpcServerEndpoint, dialOpts)
	if err != nil {
		return err
	}

	// Start HTTP server (and proxy calls to gRPC server endpoint)
	return http.ListenAndServe(":8081", mux)
}

func main() {
	flag.Parse()
	defer glog.Flush()

	if err := run(); err != nil {
		glog.Fatal(err)
	}
}
